==> craft_parts-2.10.0-py3-none-any.whl: craft_parts/plugins/nil_plugin.py <==
# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
#
# Copyright 2020,2024 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License version 3 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The nil plugin.

Using this, parts can be defined purely by utilizing properties that are
automatically included, e.g. stage-packages.
"""

from typing import Literal

from overrides import override

from .base import Plugin
from .properties import PluginProperties


class NilPluginProperties(PluginProperties, frozen=True):
    """The part properties used by the nil plugin."""

    plugin: Literal["nil"] = "nil"


class NilPlugin(Plugin):
    """A plugin that defines no build commands.

    The nil plugin is useful in two contexts:

    First, it can be used for parts that identify no source, and can
    be defined purely by using built-in part properties such as
    ``stage-packages``.

    The second use is for parts that do define a source (which will be
    fetched), but for which the build step then needs to be explicitly
    defined using ``override-build``; otherwise, even though the source
    is fetched, nothing will end up in that part's install directory. In
    short, for the case of a part that uses the nil plugin and defines a
    source, it is up to the developer to then define the ``override-build``
    step that, in some way, populates the ``$CRAFT_PART_INSTALL`` directory.
    """

    properties_class = NilPluginProperties

    supports_strict_mode = True

    @override
    def get_build_snaps(self) -> set[str]:
        """Return a set of required snaps to install in the build environment."""
        return set()

    @override
    def get_build_packages(self) -> set[str]:
        """Return a set of required packages to install in the build environment."""
        return set()

    @override
    def get_build_environment(self) -> dict[str, str]:
        """Return a dictionary with the environment to use in the build step."""
        return {}

    @override
    def get_pull_commands(self) -> list[str]:
        """Return a list commands to retrieve dependencies during the pull step."""
        return []

    @override
    def get_build_commands(self) -> list[str]:
        """Return a list of commands to run during the build step."""
        return []

==> craft_parts-2.26.0-py3-none-any.whl: craft_parts/plugins/nil_plugin.py <==
# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
#
# Copyright 2020,2024 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License version 3 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The nil plugin.

Using this, parts can be defined purely by utilizing properties that are
automatically included, e.g. stage-packages.
"""

from typing import Literal

from typing_extensions import override

from .base import Plugin
from .properties import PluginProperties


class NilPluginProperties(PluginProperties, frozen=True):
    """The part properties used by the nil plugin."""

    plugin: Literal["nil"] = "nil"


class NilPlugin(Plugin):
    """A plugin that defines no build commands.

    The nil plugin is useful in two contexts:

    First, it can be used for parts that identify no source, and can
    be defined purely by using built-in part properties such as
    ``stage-packages``.

    The second use is for parts that do define a source (which will be
    fetched), but for which the build step then needs to be explicitly
    defined using ``override-build``; otherwise, even though the source
    is fetched, nothing will end up in that part's install directory. In
    short, for the case of a part that uses the nil plugin and defines a
    source, it is up to the developer to then define the ``override-build``
    step that, in some way, populates the ``$CRAFT_PART_INSTALL`` directory.
    """

    properties_class = NilPluginProperties

    supports_strict_mode = True

    @override
    def get_build_snaps(self) -> set[str]:
        """Return a set of required snaps to install in the build environment."""
        return set()

    @override
    def get_build_packages(self) -> set[str]:
        """Return a set of required packages to install in the build environment."""
        return set()

    @override
    def get_build_environment(self) -> dict[str, str]:
        """Return a dictionary with the environment to use in the build step."""
        return {}

    @override
    def get_pull_commands(self) -> list[str]:
        """Return a list commands to retrieve dependencies during the pull step."""
        return []

    @override
    def get_build_commands(self) -> list[str]:
        """Return a list of commands to run during the build step."""
        return []
